@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11388 2019-03-20 08:36:54Z Lavender $
+# $Id: __init__.py 11500 2019-04-30 18:49:58Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-03-20 17:36:54 +0900 (週三, 20 三月 2019) $
-# $Revision: 11388 $
+# $Date: 2019-05-01 03:49:58 +0900 (週三, 01 五月 2019) $
+# $Revision: 11500 $
 
 import os
 import sys
@@ -116,6 +116,7 @@ def attachSettings(settingsDict):
             'Zephyrus.blog_extension',
             'Zephyrus.comment',
             'django_gravatar',
+            'captcha',
         ]
 
     if ZEPHYRUS_OSCAR_ENABLE:
@@ -241,17 +242,34 @@ def attachSettings(settingsDict):
                 },
             }
         else:
-            HAYSTACK_SETTINGS = {
-                'HAYSTACK_CONNECTIONS': {
-                    'default': {
-                        'ENGINE': 'xapian_backend.XapianEngine',
-                        'PATH': os.path.join(BASE_DIR, 'xapian_index'),
-                        # 這個在執行 rebuild index 會爆炸
-                        'EXCLUDED_INDEXES': [
-                            'aldryn_people.search_indexes.PeopleIndex'],
+            try:
+                import xapain
+                HAYSTACK_SETTINGS = {
+                    'HAYSTACK_CONNECTIONS': {
+                        'default': {
+                            'ENGINE': 'xapian_backend.XapianEngine',
+                            'PATH': os.path.join(BASE_DIR, 'xapian_index'),
+                            # 這個在執行 rebuild index 會爆炸
+                            'EXCLUDED_INDEXES': [
+                                'aldryn_people.search_indexes.PeopleIndex'],
+                        },
                     },
-                },
-            }
+                }
+            except Exception as e:
+                HAYSTACK_SETTINGS = {
+                    'HAYSTACK_CONNECTIONS': {
+                        'default': {
+                            'ENGINE': (
+                                'haystack.backends.whoosh_backend.WhooshEngine'
+                            ),
+                            'PATH': os.path.join(BASE_DIR, 'whoosh_index'),
+                            # 這個在執行 rebuild index 會爆炸
+                            'EXCLUDED_INDEXES': [
+                                'aldryn_people.search_indexes.PeopleIndex'
+                            ],
+                        },
+                    },
+                }
 
         if not 'HAYSTACK_CONNECTIONS' in settingsDict:
             update(settingsDict, HAYSTACK_SETTINGS)
