@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11479 2019-04-22 11:33:41Z Lavender $
+# $Id: build_boilerplate2.py 11497 2019-04-24 18:53:30Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-22 20:33:41 +0900 (週一, 22 四月 2019) $
-# $Revision: 11479 $
+# $Date: 2019-04-25 03:53:30 +0900 (週四, 25 四月 2019) $
+# $Revision: 11497 $
 
 import os
 import re
@@ -528,6 +528,9 @@ class Command(BaseCommand):
         cmsDiv.tail = '\n'
 
         body.append(cmsDiv)
+        
+        if not body.text:
+            body.text = ''
 
         # add cms data to body
         if body.getchildren():
