@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 11436 2019-04-10 17:56:15Z Lavender $
+# $Id: pluginize.py 11461 2019-04-16 18:26:42Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
-# $Revision: 11436 $
+# $Date: 2019-04-17 03:26:42 +0900 (週三, 17 四月 2019) $
+# $Revision: 11461 $
 
 import os
 import json
@@ -43,9 +43,10 @@ from lxml.html import fromstring
 from html5lib import sanitizer
 from html5lib.filters import sanitizer as filtersSanitizer
 
+from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, 
-    FIXTURES_DIR_PATH, ROOT_DIR_PATH, DJANGO_VERSION)
+    FIXTURES_DIR_PATH, ROOT_DIR_PATH)
 from Zephyrus.boilerplate.management.commands import (
     createLogger, CSS_PROPERTIES, toBytes)
 from Zephyrus.boilerplate.management.commands import open3 as open
@@ -376,7 +377,7 @@ class Command(BaseCommand):
             # build CMSContext.js
             if cms.__version__.startswith('3.4'):
                 temp = get_template('boilerplate/js/CMSContext.js')
-                if DJANGO_VERSION >= 210: # django >= 1.11
+                if DJANGO_VERSION >= 11100: # django >= 1.11
                     replaceStr = {
                         'tagList': newTagList, 
                     }
