@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11489 2019-04-24 06:45:44Z Lavender $
+# $Id: cms_plugins.py 11500 2019-04-30 18:49:58Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-24 15:45:44 +0900 (週三, 24 四月 2019) $
-# $Revision: 11489 $
+# $Date: 2019-05-01 03:49:58 +0900 (週三, 01 五月 2019) $
+# $Revision: 11500 $
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -23,6 +23,7 @@ from django.template.loader import select_template
 from Zephyrus.comment import settings as _settings
 from Zephyrus.comment.models import (
     CommentPlugin, Comment, RecentResponsePlugin, CommentConfig)
+from Zephyrus.comment.forms import CommentForm
 
 class CMSCommentPlugin(CMSPluginBase):
     model = CommentPlugin
@@ -53,6 +54,7 @@ class CMSCommentPlugin(CMSPluginBase):
             'plugin': instance,
             'url': url,
             'comments': comments,
+            'form': CommentForm(),
         })
         return context
 
