@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11489 2019-04-24 06:45:44Z Lavender $
+# $Id: models.py 11502 2019-05-01 05:37:40Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-24 15:45:44 +0900 (週三, 24 四月 2019) $
-# $Revision: 11489 $
+# $Date: 2019-05-01 14:37:40 +0900 (週三, 01 五月 2019) $
+# $Revision: 11502 $
 
 import datetime
 
@@ -26,6 +26,11 @@ from Zephyrus.comment import settings as _settings
 
 class CommentPlugin(CMSPlugin):
     useFbComment = models.BooleanField(_('Use Facebook Comment'))
+    
+    emailTo = models.CharField(
+        _('Send form data to e-mail address'), max_length=255, blank=True,
+        help_text=_('Separate several addresses with a comma.'), default=""
+    )
 
     renderTemplate = models.CharField(
         _('Comment Template'), max_length=150,
