@@ -19,16 +19,36 @@ import requests
 import json
 
 from django import template
+from django.conf import settings
 from django.utils.http import urlquote
 
 register = template.Library()
 
 def getApiData(url, fieldName):
-    apiUrl = (('https://graph.facebook.com/v2.1/'
-              '%s?fields=share&method=get&pretty=0&sdk=joey&'
-              'suppress_http_code=1') % urlquote(url))
+    accessToken = '%s|%s' % (
+        settings.SOCIAL_AUTH_FACEBOOK_KEY, 
+        settings.SOCIAL_AUTH_FACEBOOK_SECRET
+    )
+    apiUrl = (
+        'https://graph.facebook.com/v3.3/'
+        '?id=%s&fields=engagement&access_token=%s' % (
+        urlquote(url), accessToken)
+    )
     data = json.loads(requests.get(apiUrl).text)
-    return data.get("share", {}).get(fieldName, None)
+    if fieldName == "comment_count":
+        # comment_plugin_count
+        fieldName = "comment_plugin_count"
+        return data.get("engagement", {}).get(fieldName, None)
+    if fieldName == "share_count":
+        # like
+        fieldName = 'reaction_count'
+        reaction = data.get("engagement", {}).get(fieldName, 0)
+        fieldName = "comment_count"
+        comment = data.get("engagement", {}).get(fieldName, 0)
+        fieldName = 'share_count'
+        share = data.get("engagement", {}).get(fieldName, 0)
+        return reaction + share + comment
+    return data.get("engagement", {}).get(fieldName, None)
 
 
 @register.simple_tag(takes_context=True)
